ActiveKnowledgeBase

Trait ActiveKnowledgeBase 

pub trait ActiveKnowledgeBase: KnowledgeBaseTrait {
    // Required methods
    fn start_target(&mut self) -> Result<(), String>;
    fn stop_target(&mut self) -> Result<(), String>;
    fn submit_word(&mut self, word: &Word) -> Result<Word, String>;
    fn is_target_running(&self) -> bool;
}
Trait representing an active knowledge base that can submit queries to a target

Required Methods

fn start_target(&mut self) -> Result<(), String>

Starts the target system for querying

fn stop_target(&mut self) -> Result<(), String>

Stops the target system after querying

fn submit_word(&mut self, word: &Word) -> Result<Word, String>

Submits a word to the target and returns the output

fn is_target_running(&self) -> bool

Gets the current state of the target (started or stopped)

Implementors