In-memory fake active knowledge base backed by an automaton.
Structs
- Fake
Active Knowledge Base - A test implementation of an active knowledge base that uses a preset automata
In-memory fake active knowledge base backed by an automaton.