pub trait EquivalenceTest {
// Required method
fn find_counterexample(
&self,
hypothesis: &mut Automata,
) -> Option<Counterexample>;
}Expand description
Trait for equivalence testing methods
Required Methods
Sourcefn find_counterexample(
&self,
hypothesis: &mut Automata,
) -> Option<Counterexample>
fn find_counterexample( &self, hypothesis: &mut Automata, ) -> Option<Counterexample>
Find a counterexample for the given hypothesis Returns None if the automaton is equivalent to the system under learning